Welcome to the official Stockstir Library documentation!
=============================================================

**Stockstir**

Easily gather stock data of any company in any of your Python projects

.. image:: img/stockstir_logo.png

.. raw:: html

   <p align="center">
       <img src="https://img.shields.io/badge/License-MIT-brightgreen.svg" alt="Badge 1" width="100">
       <img src="https://img.shields.io/badge/Creator-PatzEdi-brightgreen.svg" alt="Badge 2" width="100">
       <img src="https://readthedocs.org/projects/stockstir/badge/?version=latest" alt="Badge 3" width="100">
       <img src="https://img.shields.io/badge/Version-Latest-brightgreen.svg" alt="Badge 3" width="100">
   </p>

.. note::

   This documentation could change as time passes in case something gets edited or changed.

Index
-----

.. toctree::
   installation
   code structure
   function use
   cli
   credits
